import sysconfig
from pathlib import Path


def get_lock_file_path(lock_file_dir: Path):
    return lock_file_dir / Path(
        f"Pipfile.{sysconfig.get_python_version()}.{sysconfig.get_platform()}.lock"
    )



import os
import subprocess
import sys
from pathlib import Path

from .utils import get_lock_file_path

LOCKFILE_DIR = Path(os.environ.get("PIPENVD_LOCKFILE_DIR", ".pipenv-d"))
if not LOCKFILE_DIR.exists():
    LOCKFILE_DIR.mkdir(parents=True)


def _run_pipenv():
    pipenv_cmd = [sys.executable, "-m", "pipenv"] + sys.argv[1:]
    return subprocess.call(pipenv_cmd)


def cli():
    lockfile_path = get_lock_file_path(LOCKFILE_DIR)
    active_lockfile = Path("Pipfile.lock")
    if lockfile_path.exists():
        with active_lockfile.open("w", encoding="utf8") as out_fid, lockfile_path.open(
            "r", encoding="utf8"
        ) as in_fid:
            out_fid.write(in_fid.read())
    ret_code = _run_pipenv()
    if active_lockfile.exists():
        with lockfile_path.open("w", encoding="utf8") as out_fid, active_lockfile.open(
            "r", encoding="utf8"
        ) as in_fid:
            out_fid.write(in_fid.read())
        active_lockfile.unlink()
    return ret_code



from pathlib import Path

from setuptools import find_packages, setup


def _get_version():
    version_file_path = Path(__file__).parent / "pipenv_d" / "_version.py"
    if not version_file_path.exists():
        print(f"WARN: no {version_file_path} found, using 0.0.0 as __version__")
        return "0.0.0"
    ns = {}
    with version_file_path.open("r") as fid:
        exec(fid.read(), {}, ns)
    return ns["__version__"]


with open("./README.md", "r") as fid:
    LONG_DESCRIPTION = fid.read()

setup(
    name="pipenv-d",
    version=_get_version(),
    description="dirty hack of pipenv",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages("."),
    install_requires=["pipenv"],
    author="dboyliao",
    url="https://github.com/dboyliao/pipenv-d",
    entry_points={"console_scripts": ["pipenv-d=pipenv_d.cli:cli"]},
)
